==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/libs/guiutils/KoRuler.h <==
/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
   Copyright (C) 2006 Peter Simonsson <peter.simonsson@gmail.com>
   Copyright (C) 2007 Casper Boemann <cbr@boemann.dk>
   Copyright (C) 2007 Thomas Zander <zander@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

// Description: Ruler (header)

/******************************************************************/

#ifndef koRuler_h
#define koRuler_h

#include <QWidget>

#include <koguiutils_export.h>
#include <KoUnit.h>

class QPaintEvent;

class KoViewConverter;

class KoRulerPrivate;

/**
 * Decorator widget to draw a single ruler around a canvas.
 */
class KOGUIUTILS_EXPORT KoRuler : public QWidget
{
    Q_OBJECT
    public:
        /**
         * Creates a ruler with the orientation @p orientation
         * @param parent parent widget
         * @param orientation the orientation of the ruler
         * @param viewConverter the view converter used to convert from point to pixel
         */
        KoRuler(QWidget* parent, Qt::Orientation orientation, const KoViewConverter* viewConverter);
        ~KoRuler();

        /// enum for a type of tabulator used
        enum TabType {
            LeftTab,        ///< A left-tab
            RightTab,       ///< A right-tab
            CenterTab,      ///< A centered-tab
            DelimiterTab    ///< A tab stopping at a certain delimiter-character
        };

        /// For paragraphs each tab definition is represented by this struct.
        struct Tab {
            double position;    ///< distance in point from the start of the text-shape
            TabType type;       ///< Determine which type is used.
        };

        /// The ruler's unit
        KoUnit unit() const;

        /// The length of the ruler in points (pt)
        double rulerLength() const;

        /// The orientation of the ruler
        Qt::Orientation orientation() const;

        /// The start indent of the first line
        double firstLineIndent() const;

        /// The start indent of the rest of the lines
        double paragraphIndent() const;

        /// The end indent of all lines
        double endIndent() const;

        /// The tab chooser widget, which you must put into a layout along with the ruler.
        /// Returns 0 for vertical rulers,
        QWidget *tabChooser();

        virtual QSize minimumSizeHint() const;
        virtual QSize sizeHint() const;

    public slots:
        /// Set the unit of the ruler
        void setUnit(KoUnit unit);

        /** Set the offset. Use this function to sync the ruler with
          * the canvas' position on screen
          * @param offset The offset in pixels
          */
        void setOffset(int offset);

        /// Sets the length of the ruler to @p length in points (pt)
        void setRulerLength(double length);

        /** Set the active range, ie the part of the ruler that is most likely used.
          * set to 0, 0 when there is no longer any active range
          * @param start the start of the range in pt
          * @param end the end of the range in pt
          */
        void setActiveRange(double start, double end);

        /** Set the state of the ruler so that it shows everything in right to left mode.
          * @param isRightToLeft state of right to left mode. Default is false.
          */
        void setRightToLeft(bool isRightToLeft);

        /** Set if the ruler should show indents as used in textditors.
          * Set the indents with setFirstLineIndent(), setParagraphIndent(), setEndIndent() .
          * @param show show indents if true. Default is false.
          */
        void setShowIndents(bool show);

        /** Set the position of the first line start indent relative to the active range.
          * If Right To left is set the indent is relative to the right side of the active range .
          * @param indent the value relative to the active range.
          */
        void setFirstLineIndent(double indent);

        /** Set the position of the rest of the lines start indent relative to the active range.
          * If Right To left is set the indent is relative to the right side of the active range .
          * @param indent the value relative to the active range.
          */
        void setParagraphIndent(double indent);

        /** Set the position of the end indent relative to the active range.
          * If Right To left is set the indent is relative to the left side of the active range .
          * @param indent the value relative to the active range.
          */
        void setEndIndent(double indent);

        /** Set wether the ruler should show the current mouse position.
          * Update the position with updateMouseCoordinate().
          * @param show show mouse position if true. Default is false.
          */
        void setShowMousePosition(bool show);

        /** Update the current position of the mouse pointer, repainting if changed.
          * The ruler offset will be applied before painting.
          * @param coordinate Either the x or y coordinate of the mouse depending
          *                   of the orientation of the ruler.
          */
        void updateMouseCoordinate(int coordinate);

        /**
         * Set whether the ruler should show the selection borders
         * @param show show selection borders if true, default is false.
         */
        void setShowSelectionBorders(bool show);

        /**
         * Update the selection borders
         * @param first the first selection border in points
         * @param second the other selection border in points
         */
        void updateSelectionBorders(double first, double second);

        /**
         * Set whether the ruler should show tabs
         * @param show show selection borders if true, default is false.
         */
        void setShowTabs(bool show);

        /**
         * Update the tabs
         * @param tabs a list of tabs that is shown on the ruler the first selection border in points
         */
        void updateTabs(const QList<Tab> &tabs);

    QList<Tab> tabs() const;

signals:
        /**
         * emitted when any of the indents is moved by the user.
         * @param final false until the user releases the mouse. So you can implement live update.
         */
        void indentsChanged(bool final);

        /**
         * emitted when any of the tabs is moved, deleted or inserted by the user.
         * @param final false until the user releases the mouse. So you can implement live update.
         */
        void tabsChanged(bool final);

    protected:
        virtual void paintEvent(QPaintEvent* event);
        virtual void mousePressEvent ( QMouseEvent* ev );
        virtual void mouseReleaseEvent ( QMouseEvent* ev );
        virtual void mouseMoveEvent ( QMouseEvent* ev );

        /// @return The step in unit between numbers on the ruler
        double numberStepForUnit() const;

    private:
        KoRulerPrivate * const d;
};

#endif

==> koffice2_1.9.95.orig.tar.gz: koffice-1.9.95/libs/guiutils/KoRuler.h <==
/* This file is part of the KDE project
   Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
   Copyright (C) 2006 Peter Simonsson <peter.simonsson@gmail.com>
   Copyright (C) 2007 Casper Boemann <cbr@boemann.dk>
   Copyright (C) 2007 Thomas Zander <zander@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

// Description: Ruler (header)

/******************************************************************/

#ifndef koRuler_h
#define koRuler_h


#include "koguiutils_export.h"
#include <kdeversion.h>
#include <KoUnit.h>

#include <QWidget>
#include <QTextOption>

class QPaintEvent;

class KoViewConverter;

class KoRulerPrivate;

/**
 * Decorator widget to draw a single ruler around a canvas.
 */
class KOGUIUTILS_EXPORT KoRuler : public QWidget
{
Q_OBJECT
public:
        /**
         * Creates a ruler with the orientation @p orientation
         * @param parent parent widget
         * @param orientation the orientation of the ruler
         * @param viewConverter the view converter used to convert from point to pixel
         */
        KoRuler(QWidget* parent, Qt::Orientation orientation, const KoViewConverter* viewConverter);
        ~KoRuler();

#if QT_VERSION < KDE_MAKE_VERSION(4,4,0) // remove when 4.4 is mandatory
        /// enum for a type of tabulator used
        enum TabType {
            LeftTab,        ///< A left-tab
            RightTab,       ///< A right-tab
            CenterTab,      ///< A centered-tab
            DelimiterTab    ///< A tab stopping at a certain delimiter-character
        };
#endif

        /// For paragraphs each tab definition is represented by this struct.
        struct Tab {
            double position;    ///< distance in point from the start of the text-shape
#if QT_VERSION >= KDE_MAKE_VERSION(4,4,0)
        QTextOption::
#endif
            TabType type;       ///< Determine which type is used.
        };

        /// The ruler's unit
        KoUnit unit() const;

        /// The length of the ruler in points (pt)
        double rulerLength() const;

        /// The orientation of the ruler
        Qt::Orientation orientation() const;

        /// The start indent of the first line
        double firstLineIndent() const;

        /// The start indent of the rest of the lines
        double paragraphIndent() const;

        /// The end indent of all lines
        double endIndent() const;

        /// The tab chooser widget, which you must put into a layout along with the ruler.
        /// Returns 0 for vertical rulers,
        QWidget *tabChooser();

    /**
     * set a list of actions that will be shown in a popup should the user right click on this ruler.
     * @param popupActionList the list of actions
     * @see popupActionList()
     */
    void setPopupActionList(const QList<QAction*> &popupActionList);
    /**
     * Return the actions list.
     * @see setPopupActionList()
     */
    QList<QAction*> popupActionList() const;

    public slots:
        /// Set the unit of the ruler
        void setUnit(KoUnit unit);

        /** Set the offset. Use this function to sync the ruler with
          * the canvas' position on screen
          * @param offset The offset in pixels
          */
        void setOffset(int offset);

        /// Sets the length of the ruler to @p length in points (pt)
        void setRulerLength(double length);

        /** Set the active range, ie the part of the ruler that is most likely used.
          * set to 0, 0 when there is no longer any active range
          * @param start the start of the range in pt
          * @param end the end of the range in pt
          */
        void setActiveRange(double start, double end);

        /** Set the state of the ruler so that it shows everything in right to left mode.
          * @param isRightToLeft state of right to left mode. Default is false.
          */
        void setRightToLeft(bool isRightToLeft);

        /** Set if the ruler should show indents as used in textditors.
          * Set the indents with setFirstLineIndent(), setParagraphIndent(), setEndIndent() .
          * @param show show indents if true. Default is false.
          */
        void setShowIndents(bool show);

        /** Set the position of the first line start indent relative to the active range.
          * If Right To left is set the indent is relative to the right side of the active range .
          * @param indent the value relative to the active range.
          */
        void setFirstLineIndent(double indent);

        /** Set the position of the rest of the lines start indent relative to the active range.
          * If Right To left is set the indent is relative to the right side of the active range .
          * @param indent the value relative to the active range.
          */
        void setParagraphIndent(double indent);

        /** Set the position of the end indent relative to the active range.
          * If Right To left is set the indent is relative to the left side of the active range .
          * @param indent the value relative to the active range.
          */
        void setEndIndent(double indent);

        /** Set wether the ruler should show the current mouse position.
          * Update the position with updateMouseCoordinate().
          * @param show show mouse position if true. Default is false.
          */
        void setShowMousePosition(bool show);

        /** Update the current position of the mouse pointer, repainting if changed.
          * The ruler offset will be applied before painting.
          * @param coordinate Either the x or y coordinate of the mouse depending
          *                   of the orientation of the ruler.
          */
        void updateMouseCoordinate(int coordinate);

        /**
         * Set whether the ruler should show the selection borders
         * @param show show selection borders if true, default is false.
         */
        void setShowSelectionBorders(bool show);

        /**
         * Update the selection borders
         * @param first the first selection border in points
         * @param second the other selection border in points
         */
        void updateSelectionBorders(double first, double second);

        /**
         * Set whether the ruler should show tabs
         * @param show show selection borders if true, default is false.
         */
        void setShowTabs(bool show);

        /**
         * Update the tabs
         * @param tabs a list of tabs that is shown on the ruler the first selection border in points
         */
        void updateTabs(const QList<Tab> &tabs);

    /***
     * Return the list of tabs set on this ruler.
     */
    QList<Tab> tabs() const;

    /**
     * Clear all previously set hotspots.
     * A hotspot is a position on the ruler that the user can manipulate by dragging.
     */
    void clearHotSpots();

    /**
     * Add or set a hotspot.
     * A hotspot is a position on the ruler that the user can manipulate by dragging.
     * @param position the new position of the hotspot.
     * @param id the unique id for the hotspot. If the id has not been set before, it will be added.
     */
    void setHotSpot(qreal position, int id = -1);

    /**
     * Remove a previously set hotspot, returning true if one is actually returned.
     * @param id the unique id for the hotspot.
     * A hotspot is a position on the ruler that the user can manipulate by dragging.
     */
    bool removeHotSpot(int id);

signals:
        /**
         * emitted when any of the indents is moved by the user.
         * @param final false until the user releases the mouse. So you can implement live update.
         */
        void indentsChanged(bool final);

        /**
         * emitted when any of the tabs is moved, deleted or inserted by the user.
         * @param final false until the user releases the mouse. So you can implement live update.
         */
        void tabsChanged(bool final);

    void hotSpotChanged(int id, qreal newPosition);

protected:
        virtual void paintEvent(QPaintEvent* event);
        virtual void mousePressEvent ( QMouseEvent* ev );
        virtual void mouseReleaseEvent ( QMouseEvent* ev );
        virtual void mouseMoveEvent ( QMouseEvent* ev );
    virtual QSize minimumSizeHint() const;
    virtual QSize sizeHint() const;


private:
        KoRulerPrivate * const d;
};

#endif
